/* Copyright (C) 1991-2015 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, see
   <http://www.gnu.org/licenses/>.  */


/* This header is separate from features.h so that the compiler can
   include it implicitly at the start of every compilation.  It must
   not itself include <features.h> or any other header that includes
   <features.h> because the implicit include comes before any feature
   test macros that may be defined in a source file before it first
   explicitly includes a system header.  GCC knows the name of this
   header in order to preinclude it.  */

/* glibc's intent is to support the IEC 559 math functionality, real
   and complex.  If the GCC (4.9 and later) predefined macros
   specifying compiler intent are available, use them to determine
   whether the overall intent is to support these features; otherwise,
   presume an older compiler has intent to support these features and
   define these macros by default.  */



/* wchar_t uses Unicode 7.0.0.  Version 7.0 of the Unicode Standard is
   synchronized with ISO/IEC 10646:2012, plus Amendments 1 (published
   on April, 2013) and 2 (not yet published as of February, 2015).
   Additionally, it includes the accelerated publication of U+20BD
   RUBLE SIGN.  Therefore Unicode 7.0.0 is between 10646:2012 and
   10646:2014, and so we use the date ISO/IEC 10646:2012 Amd.1 was
   published.  */

/* We do not support C11 <threads.h>.  */

!
! Copyright (C) 2001 PWSCF group
! This file is distributed under the terms of the
! GNU General Public License. See the file `License'
! in the root directory of the present distribution,
! or http://www.gnu.org/copyleft/gpl.txt .
!
!
!-----------------------------------------------------------------------
subroutine allocate_d3
  !-----------------------------------------------------------------------
  !
  ! dynamical allocation of arrays: quantities needed for the third
  ! derivative of the total energy
  !
  USE ions_base,  ONLY : nat, ntyp => nsp
  USE uspp,       ONLY : nkb, vkb
  use pwcom
  use phcom
  use d3com
  implicit none

  call allocate_phq
  if (lgamma) then
     vlocg0 => vlocq
     npertg0=> npert
     vkb0 => vkb
     ug0 => u
  else
     allocate (vlocg0( ngm, ntyp))
     allocate (ug0( 3*nat, 3*nat))
     allocate (npertg0( 3*nat))
     allocate (vkb0( npwx , nkb))
  endif
  allocate (psidqvpsi( nbnd, nbnd))
  allocate (d3dyn( 3 * nat, 3 * nat, 3 * nat))

  if (degauss.ne.0.d0) allocate (ef_sh( 3 * nat))
  allocate (d3dyn_aux1 ( 3 * nat, 3 * nat, 3 * nat))
  allocate (d3dyn_aux2 ( 3 * nat, 3 * nat, 3 * nat))
  allocate (d3dyn_aux3 ( 3 * nat, 3 * nat, 3 * nat))
  allocate (d3dyn_aux4 ( 3 * nat, 3 * nat, 3 * nat))
  allocate (d3dyn_aux5 ( 3 * nat, 3 * nat, 3 * nat))
  allocate (d3dyn_aux6 ( 3 * nat, 3 * nat, 3 * nat))
  allocate (d3dyn_aux7 ( 3 * nat, 3 * nat, 3 * nat))
  allocate (d3dyn_aux8 ( 3 * nat, 3 * nat, 3 * nat))
  allocate (d3dyn_aux9 ( 3 * nat, 3 * nat, 3 * nat))
  d3dyn_aux1 (:,:,:) = (0.d0, 0.d0)
  d3dyn_aux2 (:,:,:) = (0.d0, 0.d0)
  d3dyn_aux3 (:,:,:) = (0.d0, 0.d0)
  d3dyn_aux4 (:,:,:) = (0.d0, 0.d0)
  d3dyn_aux5 (:,:,:) = (0.d0, 0.d0)
  d3dyn_aux6 (:,:,:) = (0.d0, 0.d0)
  d3dyn_aux7 (:,:,:) = (0.d0, 0.d0)
  d3dyn_aux8 (:,:,:) = (0.d0, 0.d0)
  d3dyn_aux9 (:,:,:) = (0.d0, 0.d0)

  return
end subroutine allocate_d3
