/* Copyright (C) 1991-2015 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, see
   <http://www.gnu.org/licenses/>.  */


/* This header is separate from features.h so that the compiler can
   include it implicitly at the start of every compilation.  It must
   not itself include <features.h> or any other header that includes
   <features.h> because the implicit include comes before any feature
   test macros that may be defined in a source file before it first
   explicitly includes a system header.  GCC knows the name of this
   header in order to preinclude it.  */

/* glibc's intent is to support the IEC 559 math functionality, real
   and complex.  If the GCC (4.9 and later) predefined macros
   specifying compiler intent are available, use them to determine
   whether the overall intent is to support these features; otherwise,
   presume an older compiler has intent to support these features and
   define these macros by default.  */



/* wchar_t uses Unicode 7.0.0.  Version 7.0 of the Unicode Standard is
   synchronized with ISO/IEC 10646:2012, plus Amendments 1 (published
   on April, 2013) and 2 (not yet published as of February, 2015).
   Additionally, it includes the accelerated publication of U+20BD
   RUBLE SIGN.  Therefore Unicode 7.0.0 is between 10646:2012 and
   10646:2014, and so we use the date ISO/IEC 10646:2012 Amd.1 was
   published.  */

/* We do not support C11 <threads.h>.  */

!
! Copyright (C) 2001 PWSCF group
! This file is distributed under the terms of the
! GNU General Public License. See the file `License'
! in the root directory of the present distribution,
! or http://www.gnu.org/copyleft/gpl.txt .
!
!
!-----------------------------------------------------------------------
SUBROUTINE stop_d3 (flag)
!-----------------------------------------------------------------------
!
!    This routine closes all files before stopping
!    flag is no longer used
!
  USE pwcom
  USE phcom
  USE d3com
  USE control_flags, ONLY : twfcollect
  USE io_files,      ONLY : iunigk
  USE mp_global,     ONLY : me_pool, root_pool, mp_global_end

  IMPLICIT NONE

  LOGICAL :: flag

  IF (twfcollect ) THEN
     CLOSE (unit = iuwfc, status = 'delete')
  ELSE
     CLOSE (unit = iuwfc, status = 'keep')
  END IF
  CLOSE (unit = iubar, status = 'keep')
  CLOSE (unit = iudwf, status = 'keep')

  IF ( me_pool == root_pool ) THEN
     !
     CLOSE (unit = iudrho, status = 'keep')
     IF (.NOT.lgamma) CLOSE (unit = iud0rho, status = 'keep')
     IF(nlcc_any) THEN
       CLOSE (unit = iudrho+1000, status = 'keep')
       IF (.NOT.lgamma) CLOSE (unit = iud0rho+1000, status = 'keep')
     ENDIF
     !
  END IF

  CLOSE (unit = iunigk, status = 'delete')
  IF (.NOT.lgamma) THEN
     CLOSE (unit = iud0qwf, status = 'keep')
     CLOSE (unit = iudqwf, status = 'keep')
  ENDIF
  CLOSE (unit = iupdqvp, status = 'keep')
  IF (.NOT.lgamma) CLOSE (unit = iupd0vp, status = 'keep')
  IF (degauss.NE.0.d0) THEN
     CLOSE (unit = iudpdvp_1, status = 'keep')
     IF (.NOT.lgamma) THEN
        CLOSE (unit = iudpdvp_2, status = 'keep')
        CLOSE (unit = iudpdvp_3, status = 'keep')
     ENDIF
  ENDIF
  CALL print_clock_d3

  CALL mp_global_end ()

  STOP
  RETURN
END SUBROUTINE stop_d3
