/* Copyright (C) 1991-2015 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, see
   <http://www.gnu.org/licenses/>.  */


/* This header is separate from features.h so that the compiler can
   include it implicitly at the start of every compilation.  It must
   not itself include <features.h> or any other header that includes
   <features.h> because the implicit include comes before any feature
   test macros that may be defined in a source file before it first
   explicitly includes a system header.  GCC knows the name of this
   header in order to preinclude it.  */

/* glibc's intent is to support the IEC 559 math functionality, real
   and complex.  If the GCC (4.9 and later) predefined macros
   specifying compiler intent are available, use them to determine
   whether the overall intent is to support these features; otherwise,
   presume an older compiler has intent to support these features and
   define these macros by default.  */



/* wchar_t uses Unicode 7.0.0.  Version 7.0 of the Unicode Standard is
   synchronized with ISO/IEC 10646:2012, plus Amendments 1 (published
   on April, 2013) and 2 (not yet published as of February, 2015).
   Additionally, it includes the accelerated publication of U+20BD
   RUBLE SIGN.  Therefore Unicode 7.0.0 is between 10646:2012 and
   10646:2014, and so we use the date ISO/IEC 10646:2012 Amd.1 was
   published.  */

/* We do not support C11 <threads.h>.  */

!
! Copyright (C) 2009 Quantum ESPRESSO group
! This file is distributed under the terms of the
! GNU General Public License. See the file `License'
! in the root directory of the present distribution,
! or http://www.gnu.org/copyleft/gpl.txt .
!
subroutine qdipol_cryst()
!
! This subroutine puts the dipole of Q on the crystal basis
!

USE kinds,     ONLY : DP
USE lsda_mod,  ONLY : nspin
USE uspp_param, ONLY : nh
USE spin_orb,  ONLY : lspinorb
USE cell_base, ONLY : at
USE ions_base, ONLY : nat, ityp, ntyp => nsp
USE phus,      ONLY : dpqq, dpqq_so

IMPLICIT NONE

REAL(DP) :: fact(3)
COMPLEX(DP) :: fact_so(3)
INTEGER :: nt, na, ih, jh, ipol, is

DO nt = 1, ntyp
   DO ih = 1, nh (nt)
      DO jh = 1, nh (nt)
         IF (lspinorb) THEN
            DO is=1,nspin
               DO ipol=1,3
                  fact_so(ipol)=at(1,ipol)*dpqq_so(ih,jh,is,1,nt)+  &
                                at(2,ipol)*dpqq_so(ih,jh,is,2,nt)+  &
                                at(3,ipol)*dpqq_so(ih,jh,is,3,nt)
               ENDDO
               dpqq_so(ih,jh,is,:,nt)=fact_so(:)
            ENDDO
         END IF
         DO ipol=1,3
            fact(ipol)=at(1,ipol)*dpqq(ih,jh,1,nt)+  &
                       at(2,ipol)*dpqq(ih,jh,2,nt)+  &
                       at(3,ipol)*dpqq(ih,jh,3,nt)
         ENDDO
         dpqq(ih,jh,:,nt)=fact(:)
      ENDDO
   ENDDO
ENDDO

RETURN
END SUBROUTINE qdipol_cryst
