/* Copyright (C) 1991-2015 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, see
   <http://www.gnu.org/licenses/>.  */


/* This header is separate from features.h so that the compiler can
   include it implicitly at the start of every compilation.  It must
   not itself include <features.h> or any other header that includes
   <features.h> because the implicit include comes before any feature
   test macros that may be defined in a source file before it first
   explicitly includes a system header.  GCC knows the name of this
   header in order to preinclude it.  */

/* glibc's intent is to support the IEC 559 math functionality, real
   and complex.  If the GCC (4.9 and later) predefined macros
   specifying compiler intent are available, use them to determine
   whether the overall intent is to support these features; otherwise,
   presume an older compiler has intent to support these features and
   define these macros by default.  */



/* wchar_t uses Unicode 7.0.0.  Version 7.0 of the Unicode Standard is
   synchronized with ISO/IEC 10646:2012, plus Amendments 1 (published
   on April, 2013) and 2 (not yet published as of February, 2015).
   Additionally, it includes the accelerated publication of U+20BD
   RUBLE SIGN.  Therefore Unicode 7.0.0 is between 10646:2012 and
   10646:2014, and so we use the date ISO/IEC 10646:2012 Amd.1 was
   published.  */

/* We do not support C11 <threads.h>.  */

!
! Copyright (C) 2007-2012 Quantum ESPRESSO group
! This file is distributed under the terms of the
! GNU General Public License. See the file `License'
! in the root directory of the present distribution,
! or http://www.gnu.org/copyleft/gpl.txt .
!
   SUBROUTINE compute_ux(m_loc,ux,nat)
!
!   This subroutine determines the direction of a fixed quantization axis
!   from the starting magnetization.
!
   USE kinds, ONLY : dp
   USE constants, ONLY: pi, eps12
   USE io_global,  ONLY :  stdout
   USE noncollin_module, ONLY : lsign

   IMPLICIT NONE

   INTEGER, INTENT(IN) :: nat    ! number of atoms
   REAL(DP), INTENT(OUT) :: ux(3)     ! fixed direction to calculate signs
   REAL(DP), INTENT(IN) :: m_loc(3,nat)     ! local moments
         
   REAL(DP) :: amag, uxmod ! modulus of the magnetization and of ux 

   INTEGER :: na          ! counter on atoms
   INTEGER :: starting_na ! auxiliary variable
   LOGICAL :: is_parallel ! external function true if two vectors are parallel
!
!  Do not use the sign feature in the general case
!
   lsign=.FALSE.
   ux=0.0_DP

   starting_na=0
   DO na=1,nat
      amag=m_loc(1,na)**2+m_loc(2,na)**2+m_loc(3,na)**2
      IF (amag > eps12) THEN
         ux(:)=m_loc(:,na)
         starting_na=na
         lsign=.TRUE.
         GOTO 20
      ENDIF
   ENDDO
20 CONTINUE
!
!  The sign feature is used only when all initial magnetizations are parallel
!  to a fixed direction that is taken as the quantization axis.
!
   DO na=starting_na+1, nat
      lsign=lsign.AND.is_parallel(ux,m_loc(:,na))
   ENDDO

   IF (lsign) THEN
      uxmod=ux(1)**2+ux(2)**2+ux(3)**2
      IF (uxmod<eps12) CALL errore('compute_ux','strange uxmod',1) 
      ux=ux/SQRT(uxmod)
      WRITE( stdout,'(/,5x,"Fixed quantization axis for GGA: ", 3f12.6)') &
                          ux(1), ux(2), ux(3)
   ENDIF
   RETURN
   END SUBROUTINE compute_ux
