/* Copyright (C) 1991-2015 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, see
   <http://www.gnu.org/licenses/>.  */


/* This header is separate from features.h so that the compiler can
   include it implicitly at the start of every compilation.  It must
   not itself include <features.h> or any other header that includes
   <features.h> because the implicit include comes before any feature
   test macros that may be defined in a source file before it first
   explicitly includes a system header.  GCC knows the name of this
   header in order to preinclude it.  */

/* glibc's intent is to support the IEC 559 math functionality, real
   and complex.  If the GCC (4.9 and later) predefined macros
   specifying compiler intent are available, use them to determine
   whether the overall intent is to support these features; otherwise,
   presume an older compiler has intent to support these features and
   define these macros by default.  */



/* wchar_t uses Unicode 7.0.0.  Version 7.0 of the Unicode Standard is
   synchronized with ISO/IEC 10646:2012, plus Amendments 1 (published
   on April, 2013) and 2 (not yet published as of February, 2015).
   Additionally, it includes the accelerated publication of U+20BD
   RUBLE SIGN.  Therefore Unicode 7.0.0 is between 10646:2012 and
   10646:2014, and so we use the date ISO/IEC 10646:2012 Amd.1 was
   published.  */

/* We do not support C11 <threads.h>.  */

!
! Copyright (C) 2001-2004 PWSCF group
! This file is distributed under the terms of the
! GNU General Public License. See the file `License'
! in the root directory of the present distribution,
! or http://www.gnu.org/copyleft/gpl.txt .
!
!----------------------------------------------------------------------------
SUBROUTINE rho2zeta( rho, rho_core, nrxx, nspin, iop )
  !---------------------------------------------------------------------------
  !
  ! ... if ( iopi == 1 )  transform the spin up spin down charge density 
  ! ...                   rho(*,is) into :
  !
  ! ...                      rho(*,1) = ( rho_up + rho_dw ) and
  ! ...                      rho(*,2) = ( rho_up - rho_dw ) / rho_tot = zeta
  !
  ! ... if ( iopi == -1)  do the opposit transformation
  !
  USE constants, ONLY : eps32
  USE io_global, ONLY : stdout
  USE kinds,     ONLY : DP
  !
  IMPLICIT NONE
  !
  INTEGER :: iop, nspin, nrxx, ir
    ! the input option
    ! the number of spin polarizations
    ! the fft grid dimension
    ! the counter for fft grid
  REAL(DP) :: rho(nrxx,nspin), rho_core(nrxx), &
                   rho_up, rho_dw, zeta, rhox
    ! the scf charge density
    ! the core charge density
    ! auxiliary variable for rho up
    ! auxiliary variable for rho dw
    ! auxiliary variable for zeta
    ! auxiliary variable for total rho
  !
  !
  IF ( nspin == 1 ) RETURN
  !
  IF ( iop == 1 ) THEN
     !
     DO ir = 1, nrxx
        !
        rhox = rho(ir,1) + rho(ir,2) + rho_core(ir)
        !
        IF ( rhox > eps32 ) THEN
           !
           zeta = ( rho(ir,1) - rho(ir,2) ) / rhox
           !
        ELSE
           !
           zeta = 0.D0
           !
        END IF
        !
        rho(ir,1) = rho(ir,1) + rho(ir,2)
        rho(ir,2) = zeta
        !
     END DO
     !
  ELSE IF ( iop == - 1 ) THEN
     !
     DO ir = 1, nrxx
        !
        rhox = rho(ir,1) + rho_core(ir)
        !
        rho_up = 0.5D0 * ( rho(ir,1) + rho(ir,2) * rhox )
        rho_dw = 0.5D0 * ( rho(ir,1) - rho(ir,2) * rhox )
        !
        rho(ir,1) = rho_up
        rho(ir,2) = rho_dw
        !
     END DO
     !
  ELSE
     !
     WRITE( stdout , '(5X,"iop = ",I5)' ) iop
     !
     CALL errore( 'mag2zeta', 'wrong iop', 1 )
     !
  END IF
  !
  RETURN
  !
END SUBROUTINE rho2zeta
