/* Copyright (C) 1991-2015 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, see
   <http://www.gnu.org/licenses/>.  */


/* This header is separate from features.h so that the compiler can
   include it implicitly at the start of every compilation.  It must
   not itself include <features.h> or any other header that includes
   <features.h> because the implicit include comes before any feature
   test macros that may be defined in a source file before it first
   explicitly includes a system header.  GCC knows the name of this
   header in order to preinclude it.  */

/* glibc's intent is to support the IEC 559 math functionality, real
   and complex.  If the GCC (4.9 and later) predefined macros
   specifying compiler intent are available, use them to determine
   whether the overall intent is to support these features; otherwise,
   presume an older compiler has intent to support these features and
   define these macros by default.  */



/* wchar_t uses Unicode 7.0.0.  Version 7.0 of the Unicode Standard is
   synchronized with ISO/IEC 10646:2012, plus Amendments 1 (published
   on April, 2013) and 2 (not yet published as of February, 2015).
   Additionally, it includes the accelerated publication of U+20BD
   RUBLE SIGN.  Therefore Unicode 7.0.0 is between 10646:2012 and
   10646:2014, and so we use the date ISO/IEC 10646:2012 Amd.1 was
   published.  */

/* We do not support C11 <threads.h>.  */

!
! Copyright (C) 2001 PWSCF group
! This file is distributed under the terms of the
! GNU General Public License. See the file `License'
! in the root directory of the present distribution,
! or http://www.gnu.org/copyleft/gpl.txt .
!
program prog
  implicit none
  real, allocatable :: e(:,:)
  real, allocatable :: k(:,:)
  real, dimension(3) ::k0,a
  integer nbnd, nbnd2, nks, i, n, j
  real ef, dk
  character(len=32):: input, output
  namelist/plot/ nbnd, nks

  write(6,*) 'Number of bands to be plotted:'
  read(5,*) nbnd2
  write(6,*) 'Fermi level (eV):'
  read(5,*) ef
  write(6,*) 'Name of the bands file (produced by band.x):'
  read(5,*) input
  write(6,*) 'Name of the output file:'
  read(5,*) output

  open(10,file=input, status='old')
  open(11,file=output, status='unknown')

  read(10,plot)

  if (nbnd2.gt.nbnd) nbnd2=nbnd

  allocate(e(nks,nbnd))
  allocate(k(nks,3))

  do i=1,nks
     read(10,*)(k(i,j),j=1,3)
     write(6,9020)(k(i,j),j=1,3)

     read(10,*) (e(i,n),n=1,nbnd)
     write(6,9030) (e(i,n),n=1,nbnd)

9020 format (14x,3f7.4)
9030 format (8f9.4)  
  enddo

  do j=1,nbnd2
     dk=0.0
     do i=1,nks
        if (i.eq.1) then
           k0=k(i,:)
        endif
        a=k(i,:)-k0
        dk=dk+sqrt(dot_product(a,a))

        write(11,*)dk,e(i,j)-ef
        k0=k(i,:)
     enddo
     write(11,*)
  enddo
  stop
end program prog

