/* Copyright (C) 1991-2015 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, see
   <http://www.gnu.org/licenses/>.  */


/* This header is separate from features.h so that the compiler can
   include it implicitly at the start of every compilation.  It must
   not itself include <features.h> or any other header that includes
   <features.h> because the implicit include comes before any feature
   test macros that may be defined in a source file before it first
   explicitly includes a system header.  GCC knows the name of this
   header in order to preinclude it.  */

/* glibc's intent is to support the IEC 559 math functionality, real
   and complex.  If the GCC (4.9 and later) predefined macros
   specifying compiler intent are available, use them to determine
   whether the overall intent is to support these features; otherwise,
   presume an older compiler has intent to support these features and
   define these macros by default.  */



/* wchar_t uses Unicode 7.0.0.  Version 7.0 of the Unicode Standard is
   synchronized with ISO/IEC 10646:2012, plus Amendments 1 (published
   on April, 2013) and 2 (not yet published as of February, 2015).
   Additionally, it includes the accelerated publication of U+20BD
   RUBLE SIGN.  Therefore Unicode 7.0.0 is between 10646:2012 and
   10646:2014, and so we use the date ISO/IEC 10646:2012 Amd.1 was
   published.  */

/* We do not support C11 <threads.h>.  */

!---------------------------------------------------------------
subroutine outward(y,f,g,mesh,imatch,ncross)
!---------------------------------------------------------------
   ! outward integration. numerov method.
   !
   use kinds, only: DP
   use radial_grids, only: ndmx
   implicit none
   !
   ! I/O variables
   !
   integer :: mesh,imatch, ncross
   real (DP) :: y(ndmx), f(ndmx), g(ndmx)
   !
   ! local variables
   !
   integer :: n
   real (DP) :: ymx

   if (ndmx.lt.mesh) stop ' outward : ndmx .lt. mesh !!!!'
   !
   ncross=0
   ymx=0.d0
   do n=2,imatch-1
      y(n+1)=((12.d0-10.d0*f(n))*y(n)-f(n-1)*y(n-1)+g(n))/f(n+1)
      if ( y(n) .ne. sign(y(n),y(n+1)) ) ncross=ncross+1
      ymx=max(ymx,abs(y(n)))
   end do
   if(ymx.ge.1.0d10) write (*,*) ' ******** ymx.ge.1.0e10 ********'
!
   return
end subroutine outward

